@@ -1,5 +1,5 @@
 #    Back In Time
-#    Copyright (C) 2008-2016 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze
+#    Copyright (C) 2008-2017 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -19,6 +19,7 @@ import os
 import sys
 import gettext
 import argparse
+import subprocess
 
 import config
 import logger
@@ -45,19 +46,27 @@ def take_snapshot_now_async( cfg ):
 
     cfg:    config.Config instance
     '''
-    cmd = ''
+    cmd = []
     if cfg.is_run_ionice_from_user_enabled():
-        cmd += 'ionice -c2 -n7 '
-    cmd += 'backintime '
+        cmd.extend(('ionice', '-c2', '-n7'))
+    cmd.append('backintime')
     if '1' != cfg.get_current_profile():
-        cmd += '--profile-id %s ' % cfg.get_current_profile()
-    if not cfg._LOCAL_CONFIG_PATH is cfg._DEFAULT_CONFIG_PATH:
-        cmd += '--config %s ' % cfg._LOCAL_CONFIG_PATH
+        cmd.extend(('--profile-id', str(cfg.get_current_profile())))
+    if cfg._LOCAL_CONFIG_PATH is not cfg._DEFAULT_CONFIG_PATH:
+        cmd.extend(('--config', cfg._LOCAL_CONFIG_PATH))
     if logger.DEBUG:
-        cmd += '--debug '
-    cmd += 'backup &'
+        cmd.append('--debug')
+    cmd.append('backup')
 
-    os.system( cmd )
+    # child process need to start its own ssh-agent because otherwise
+    # it would be lost without ssh-agent if parent will close
+    env = os.environ.copy()
+    for i in ('SSH_AUTH_SOCK', 'SSH_AGENT_PID'):
+        try:
+            del env[i]
+        except:
+            pass
+    subprocess.Popen(cmd, env = env)
 
 def take_snapshot( cfg, force = True ):
     '''take a new snapshot.
@@ -631,7 +640,7 @@ def backupJob(args):
 
     args:   argparse.ArgumentParser instance
     '''
-    backup(args, False)
+    cli.BackupJobDaemon(backup, args).start()
 
 def snapshotsPath(args):
     '''command for printing the full snapshot path of current profile.
