@@ -1,5 +1,5 @@
 #    Back In Time
-#    Copyright (C) 2008-2016 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze
+#    Copyright (C) 2008-2017 Oprea Dan, Bart de Koning, Richard Bailey, Germar Reitze
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -24,8 +24,10 @@ import re
 import errno
 import gzip
 import tempfile
+import atexit
 from datetime import datetime
 from distutils.version import StrictVersion
+from time import sleep
 keyring = None
 keyring_warn = False
 try:
@@ -50,6 +52,7 @@ except ImportError:
 
 import configfile
 import logger
+from applicationinstance import ApplicationInstance
 from exceptions import Timeout, InvalidChar, PermissionDeniedByPolicy
 
 ON_AC = 0
@@ -189,7 +192,7 @@ def make_dirs( path ):
             os.makedirs( path )
         except Exception as e:
             logger.error("Failed to make dirs '%s': %s"
-                         %(path, str(e)), self, 1)
+                         %(path, str(e)), traceDepth = 1)
     return os.path.isdir(path)
 
 def process_exists( name ):
@@ -597,6 +600,8 @@ def keyring_supported():
     except: pass
     try: backends.append(keyring.backends.kwallet.Keyring)
     except: pass
+    try: backends.append(keyring.backends.kwallet.DBusKeyring)
+    except: pass
     try: backends.append(keyring.backend.SecretServiceKeyring)
     except: pass
     try: backends.append(keyring.backend.GnomeKeyring)
@@ -607,9 +612,9 @@ def keyring_supported():
         displayName = keyring.get_keyring().__module__
     except:
         displayName = str(keyring.get_keyring())
-    if backends:
+    if backends and isinstance(keyring.get_keyring(), tuple(backends)):
         logger.debug("Found appropriate keyring '{}'".format(displayName))
-        return isinstance(keyring.get_keyring(), tuple(backends))
+        return True
     logger.debug("No appropriate keyring found. '{}' can't be used with BackInTime".format(displayName))
     return False
 
@@ -866,7 +871,7 @@ def writeCrontab(lines):
     assert isinstance(lines, (list, tuple)), 'lines is not list or tuple type: %s' % lines
     with tempfile.NamedTemporaryFile(mode = 'wt') as f:
         f.write('\n'.join(lines))
-        f.write('\n')
+        f.write('\n\n')
         f.flush()
         cmd = ['crontab', f.name]
         proc = subprocess.Popen(cmd,
@@ -891,6 +896,22 @@ def splitCommands(cmds, head = '', tail = '', maxLength = 0, additionalChars = 0
         s += tail
         yield s
 
+def fdDup(old, new_fd, mode = 'w'):
+    """
+    Duplicate file descriptor `old` to `new_fd` and closing the latter first.
+    Used to redirect stdin, stdout and stderr from daemonized threads.
+
+    Args:
+        old (str):                  Path to the old file (e.g. /dev/stdout)
+        new_fd (_io.TextIOWrapper): file object for the new file
+        mode (str):                 mode in which the old file should be opened
+    """
+    try:
+        fd = open(old, mode)
+        os.dup2(fd.fileno(), new_fd.fileno())
+    except OSError as e:
+        logger.debug('Failed to redirect {}: {}'.format(old, str(e)))
+
 class UniquenessSet:
     '''a class to check for uniqueness of snapshots of the same [item]'''
     def __init__(self, dc = False, follow_symlink = False, list_equal_to = False):
@@ -1268,6 +1289,171 @@ class PathHistory(object):
         self.history = [path,]
         self.index = 0
 
+class Daemon:
+    """
+    A generic daemon class.
+
+    Usage: subclass the Daemon class and override the run() method
+
+    Daemon Copyright by Sander Marechal
+    License CC BY-SA 3.0
+    http://www.jejik.com/articles/2007/02/a_simple_unix_linux_daemon_in_python/
+    """
+    def __init__(self, pidfile = None, stdin='/dev/null', stdout='/dev/stdout', stderr='/dev/null'):
+        self.stdin = stdin
+        self.stdout = stdout
+        self.stderr = stderr
+        self.pidfile = pidfile
+        if pidfile:
+            self.appInstance = ApplicationInstance(pidfile, auto_exit = False, flock = False)
+
+    def daemonize(self):
+        """
+        do the UNIX double-fork magic, see Stevens' "Advanced
+        Programming in the UNIX Environment" for details (ISBN 0201563177)
+        http://www.erlenstar.demon.co.uk/unix/faq_2.html#SEC16
+        """
+        try:
+            pid = os.fork()
+            logger.debug('first fork pid: {}'.format(pid), self)
+            if pid > 0:
+                # exit first parent
+                sys.exit(0)
+        except OSError as e:
+            logger.error("fork #1 failed: %d (%s)" % (e.errno, str(e)), self)
+            sys.exit(1)
+
+        # decouple from parent environment
+        logger.debug('decouple from parent environment', self)
+        os.chdir("/")
+        os.setsid()
+        os.umask(0)
+
+        # do second fork
+        try:
+            pid = os.fork()
+            logger.debug('second fork pid: {}'.format(pid), self)
+            if pid > 0:
+                # exit from second parent
+                sys.exit(0)
+        except OSError as e:
+            logger.error("fork #2 failed: %d (%s)" % (e.errno, str(e)), self)
+            sys.exit(1)
+
+        # redirect standard file descriptors
+        logger.debug('redirect standard file descriptors', self)
+
+        sys.stdout.flush()
+        sys.stderr.flush()
+        fdDup(self.stdin, sys.stdin, 'r')
+        fdDup(self.stdout, sys.stdout, 'w')
+        fdDup(self.stderr, sys.stderr, 'w')
+
+        signal.signal(signal.SIGTERM, self.cleanupHandler)
+        if self.pidfile:
+            atexit.register(self.appInstance.exit_application)
+            # write pidfile
+            logger.debug('write pidfile', self)
+            self.appInstance.start_application()
+
+    def cleanupHandler(self, signum, frame):
+        if self.pidfile:
+            self.appInstance.exit_application()
+        sys.exit(0)
+
+    def start(self):
+        """
+        Start the daemon
+        """
+        # Check for a pidfile to see if the daemon already runs
+        if self.pidfile and not self.appInstance.check():
+            message = "pidfile %s already exist. Daemon already running?\n"
+            logger.error(message % self.pidfile, self)
+            sys.exit(1)
+
+        # Start the daemon
+        self.daemonize()
+        self.run()
+
+    def stop(self):
+        """
+        Stop the daemon
+        """
+        if not self.pidfile:
+            logger.debug("Unattended daemon can't be stopped. No PID file", self)
+            return
+
+        # Get the pid from the pidfile
+        pid, procname = self.appInstance.readPidFile()
+
+        if not pid:
+            message = "pidfile %s does not exist. Daemon not running?\n"
+            logger.error(message % self.pidfile, self)
+            return # not an error in a restart
+
+        # Try killing the daemon process
+        try:
+            while True:
+                os.kill(pid, signal.SIGTERM)
+                sleep(0.1)
+        except OSError as err:
+            if err.errno == errno.ESRCH:
+                #no such process
+                self.appInstance.exit_application()
+            else:
+                logger.error(str(err), self)
+                sys.exit(1)
+
+    def restart(self):
+        """
+        Restart the daemon
+        """
+        self.stop()
+        self.start()
+
+    def reload(self):
+        """
+        send SIGHUP signal to process
+        """
+        if not self.pidfile:
+            logger.debug("Unattended daemon can't be reloaded. No PID file", self)
+            return
+
+        # Get the pid from the pidfile
+        pid, procname = self.appInstance.readPidFile()
+
+        if not pid:
+            message = "pidfile %s does not exist. Daemon not running?\n"
+            logger.error(message % self.pidfile, self)
+            return
+
+        # Try killing the daemon process
+        try:
+            os.kill(pid, signal.SIGHUP)
+        except OSError as err:
+            if err.errno == errno.ESRCH:
+                #no such process
+                self.appInstance.exit_application()
+            else:
+                sys.stderr.write(str(err))
+                sys.exit(1)
+
+    def status(self):
+        """
+        return status
+        """
+        if not self.pidfile:
+            logger.debug("Unattended daemon can't be checked. No PID file", self)
+            return
+        return not self.appInstance.check()
+
+    def run(self):
+        """
+        You should override this method when you subclass Daemon. It will be called after the process has been
+        daemonized by start() or restart().
+        """
+        pass
+
 def __log_keyring_warning():
     from time import sleep
     sleep(0.1)
